==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkGenericAdaptorCell.java <==
// java wrapper for vtkGenericAdaptorCell object
//

package vtk;
import vtk.*;

public class vtkGenericAdaptorCell extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetId_2();
  public int GetId()
    { return GetId_2(); }

  private native int IsInDataSet_3();
  public int IsInDataSet()
    { return IsInDataSet_3(); }

  private native int GetType_4();
  public int GetType()
    { return GetType_4(); }

  private native int GetDimension_5();
  public int GetDimension()
    { return GetDimension_5(); }

  private native int GetGeometryOrder_6();
  public int GetGeometryOrder()
    { return GetGeometryOrder_6(); }

  private native int IsGeometryLinear_7();
  public int IsGeometryLinear()
    { return IsGeometryLinear_7(); }

  private native int GetAttributeOrder_8(vtkGenericAttribute id0);
  public int GetAttributeOrder(vtkGenericAttribute id0)
    { return GetAttributeOrder_8(id0); }

  private native int GetHighestOrderAttribute_9(vtkGenericAttributeCollection id0);
  public int GetHighestOrderAttribute(vtkGenericAttributeCollection id0)
    { return GetHighestOrderAttribute_9(id0); }

  private native int IsAttributeLinear_10(vtkGenericAttribute id0);
  public int IsAttributeLinear(vtkGenericAttribute id0)
    { return IsAttributeLinear_10(id0); }

  private native int IsPrimary_11();
  public int IsPrimary()
    { return IsPrimary_11(); }

  private native int GetNumberOfPoints_12();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_12(); }

  private native int GetNumberOfBoundaries_13(int id0);
  public int GetNumberOfBoundaries(int id0)
    { return GetNumberOfBoundaries_13(id0); }

  private native int GetNumberOfDOFNodes_14();
  public int GetNumberOfDOFNodes()
    { return GetNumberOfDOFNodes_14(); }

  private native void GetPointIterator_15(vtkGenericPointIterator id0);
  public void GetPointIterator(vtkGenericPointIterator id0)
    { GetPointIterator_15(id0); }

  private native long NewCellIterator_16();
  public vtkGenericCellIterator NewCellIterator() {
    long temp = NewCellIterator_16();

    if (temp == 0) return null;
    return (vtkGenericCellIterator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void GetBoundaryIterator_17(vtkGenericCellIterator id0,int id1);
  public void GetBoundaryIterator(vtkGenericCellIterator id0,int id1)
    { GetBoundaryIterator_17(id0,id1); }

  private native int CountNeighbors_18(vtkGenericAdaptorCell id0);
  public int CountNeighbors(vtkGenericAdaptorCell id0)
    { return CountNeighbors_18(id0); }

  private native void GetNeighbors_19(vtkGenericAdaptorCell id0,vtkGenericCellIterator id1);
  public void GetNeighbors(vtkGenericAdaptorCell id0,vtkGenericCellIterator id1)
    { GetNeighbors_19(id0,id1); }

  private native void EvaluateLocation_20(int id0,double id1[],double id2[]);
  public void EvaluateLocation(int id0,double id1[],double id2[])
    { EvaluateLocation_20(id0,id1,id2); }

  private native void Contour_21(vtkContourValues id0,vtkImplicitFunction id1,vtkGenericAttributeCollection id2,vtkGenericCellTessellator id3,vtkIncrementalPointLocator id4,vtkCellArray id5,vtkCellArray id6,vtkCellArray id7,vtkPointData id8,vtkCellData id9,vtkPointData id10,vtkPointData id11,vtkCellData id12);
  public void Contour(vtkContourValues id0,vtkImplicitFunction id1,vtkGenericAttributeCollection id2,vtkGenericCellTessellator id3,vtkIncrementalPointLocator id4,vtkCellArray id5,vtkCellArray id6,vtkCellArray id7,vtkPointData id8,vtkCellData id9,vtkPointData id10,vtkPointData id11,vtkCellData id12)
    { Contour_21(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10,id11,id12); }

  private native void Clip_22(double id0,vtkImplicitFunction id1,vtkGenericAttributeCollection id2,vtkGenericCellTessellator id3,int id4,vtkIncrementalPointLocator id5,vtkCellArray id6,vtkPointData id7,vtkCellData id8,vtkPointData id9,vtkPointData id10,vtkCellData id11);
  public void Clip(double id0,vtkImplicitFunction id1,vtkGenericAttributeCollection id2,vtkGenericCellTessellator id3,int id4,vtkIncrementalPointLocator id5,vtkCellArray id6,vtkPointData id7,vtkCellData id8,vtkPointData id9,vtkPointData id10,vtkCellData id11)
    { Clip_22(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10,id11); }

  private native void GetBounds_23(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_23(id0); }

  private native double GetLength2_24();
  public double GetLength2()
    { return GetLength2_24(); }

  private native int GetParametricCenter_25(double id0[]);
  public int GetParametricCenter(double id0[])
    { return GetParametricCenter_25(id0); }

  private native double GetParametricDistance_26(double id0[]);
  public double GetParametricDistance(double id0[])
    { return GetParametricDistance_26(id0); }

  private native void Tessellate_27(vtkGenericAttributeCollection id0,vtkGenericCellTessellator id1,vtkPoints id2,vtkIncrementalPointLocator id3,vtkCellArray id4,vtkPointData id5,vtkPointData id6,vtkCellData id7,vtkUnsignedCharArray id8);
  public void Tessellate(vtkGenericAttributeCollection id0,vtkGenericCellTessellator id1,vtkPoints id2,vtkIncrementalPointLocator id3,vtkCellArray id4,vtkPointData id5,vtkPointData id6,vtkCellData id7,vtkUnsignedCharArray id8)
    { Tessellate_27(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native int IsFaceOnBoundary_28(int id0);
  public int IsFaceOnBoundary(int id0)
    { return IsFaceOnBoundary_28(id0); }

  private native int IsOnBoundary_29();
  public int IsOnBoundary()
    { return IsOnBoundary_29(); }

  private native void TriangulateFace_30(vtkGenericAttributeCollection id0,vtkGenericCellTessellator id1,int id2,vtkPoints id3,vtkIncrementalPointLocator id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8);
  public void TriangulateFace(vtkGenericAttributeCollection id0,vtkGenericCellTessellator id1,int id2,vtkPoints id3,vtkIncrementalPointLocator id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8)
    { TriangulateFace_30(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native int GetNumberOfVerticesOnFace_31(int id0);
  public int GetNumberOfVerticesOnFace(int id0)
    { return GetNumberOfVerticesOnFace_31(id0); }

  public vtkGenericAdaptorCell() { super(); }

  public vtkGenericAdaptorCell(long id) { super(id); }

}

==> vtk-8.1.2-1-aarch64.pkg.tar.xz: vtk/vtkGenericAdaptorCell.java <==
// java wrapper for vtkGenericAdaptorCell object
//

package vtk;
import vtk.*;

public class vtkGenericAdaptorCell extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetId_2();
  public int GetId()
    { return GetId_2(); }

  private native int IsInDataSet_3();
  public int IsInDataSet()
    { return IsInDataSet_3(); }

  private native int GetType_4();
  public int GetType()
    { return GetType_4(); }

  private native int GetDimension_5();
  public int GetDimension()
    { return GetDimension_5(); }

  private native int GetGeometryOrder_6();
  public int GetGeometryOrder()
    { return GetGeometryOrder_6(); }

  private native int IsGeometryLinear_7();
  public int IsGeometryLinear()
    { return IsGeometryLinear_7(); }

  private native int GetAttributeOrder_8(vtkGenericAttribute id0);
  public int GetAttributeOrder(vtkGenericAttribute id0)
    { return GetAttributeOrder_8(id0); }

  private native int GetHighestOrderAttribute_9(vtkGenericAttributeCollection id0);
  public int GetHighestOrderAttribute(vtkGenericAttributeCollection id0)
    { return GetHighestOrderAttribute_9(id0); }

  private native int IsAttributeLinear_10(vtkGenericAttribute id0);
  public int IsAttributeLinear(vtkGenericAttribute id0)
    { return IsAttributeLinear_10(id0); }

  private native int IsPrimary_11();
  public int IsPrimary()
    { return IsPrimary_11(); }

  private native int GetNumberOfPoints_12();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_12(); }

  private native int GetNumberOfBoundaries_13(int id0);
  public int GetNumberOfBoundaries(int id0)
    { return GetNumberOfBoundaries_13(id0); }

  private native int GetNumberOfDOFNodes_14();
  public int GetNumberOfDOFNodes()
    { return GetNumberOfDOFNodes_14(); }

  private native void GetPointIterator_15(vtkGenericPointIterator id0);
  public void GetPointIterator(vtkGenericPointIterator id0)
    { GetPointIterator_15(id0); }

  private native long NewCellIterator_16();
  public vtkGenericCellIterator NewCellIterator() {
    long temp = NewCellIterator_16();

    if (temp == 0) return null;
    return (vtkGenericCellIterator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetBoundaryIterator_17(vtkGenericCellIterator id0,int id1);
  public void GetBoundaryIterator(vtkGenericCellIterator id0,int id1)
    { GetBoundaryIterator_17(id0,id1); }

  private native int CountNeighbors_18(vtkGenericAdaptorCell id0);
  public int CountNeighbors(vtkGenericAdaptorCell id0)
    { return CountNeighbors_18(id0); }

  private native void GetNeighbors_19(vtkGenericAdaptorCell id0,vtkGenericCellIterator id1);
  public void GetNeighbors(vtkGenericAdaptorCell id0,vtkGenericCellIterator id1)
    { GetNeighbors_19(id0,id1); }

  private native void EvaluateLocation_20(int id0,double id1[],double id2[]);
  public void EvaluateLocation(int id0,double id1[],double id2[])
    { EvaluateLocation_20(id0,id1,id2); }

  private native void Contour_21(vtkContourValues id0,vtkImplicitFunction id1,vtkGenericAttributeCollection id2,vtkGenericCellTessellator id3,vtkIncrementalPointLocator id4,vtkCellArray id5,vtkCellArray id6,vtkCellArray id7,vtkPointData id8,vtkCellData id9,vtkPointData id10,vtkPointData id11,vtkCellData id12);
  public void Contour(vtkContourValues id0,vtkImplicitFunction id1,vtkGenericAttributeCollection id2,vtkGenericCellTessellator id3,vtkIncrementalPointLocator id4,vtkCellArray id5,vtkCellArray id6,vtkCellArray id7,vtkPointData id8,vtkCellData id9,vtkPointData id10,vtkPointData id11,vtkCellData id12)
    { Contour_21(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10,id11,id12); }

  private native void Clip_22(double id0,vtkImplicitFunction id1,vtkGenericAttributeCollection id2,vtkGenericCellTessellator id3,int id4,vtkIncrementalPointLocator id5,vtkCellArray id6,vtkPointData id7,vtkCellData id8,vtkPointData id9,vtkPointData id10,vtkCellData id11);
  public void Clip(double id0,vtkImplicitFunction id1,vtkGenericAttributeCollection id2,vtkGenericCellTessellator id3,int id4,vtkIncrementalPointLocator id5,vtkCellArray id6,vtkPointData id7,vtkCellData id8,vtkPointData id9,vtkPointData id10,vtkCellData id11)
    { Clip_22(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10,id11); }

  private native void GetBounds_23(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_23(id0); }

  private native double GetLength2_24();
  public double GetLength2()
    { return GetLength2_24(); }

  private native int GetParametricCenter_25(double id0[]);
  public int GetParametricCenter(double id0[])
    { return GetParametricCenter_25(id0); }

  private native double GetParametricDistance_26(double id0[]);
  public double GetParametricDistance(double id0[])
    { return GetParametricDistance_26(id0); }

  private native void Tessellate_27(vtkGenericAttributeCollection id0,vtkGenericCellTessellator id1,vtkPoints id2,vtkIncrementalPointLocator id3,vtkCellArray id4,vtkPointData id5,vtkPointData id6,vtkCellData id7,vtkUnsignedCharArray id8);
  public void Tessellate(vtkGenericAttributeCollection id0,vtkGenericCellTessellator id1,vtkPoints id2,vtkIncrementalPointLocator id3,vtkCellArray id4,vtkPointData id5,vtkPointData id6,vtkCellData id7,vtkUnsignedCharArray id8)
    { Tessellate_27(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native int IsFaceOnBoundary_28(int id0);
  public int IsFaceOnBoundary(int id0)
    { return IsFaceOnBoundary_28(id0); }

  private native int IsOnBoundary_29();
  public int IsOnBoundary()
    { return IsOnBoundary_29(); }

  private native void TriangulateFace_30(vtkGenericAttributeCollection id0,vtkGenericCellTessellator id1,int id2,vtkPoints id3,vtkIncrementalPointLocator id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8);
  public void TriangulateFace(vtkGenericAttributeCollection id0,vtkGenericCellTessellator id1,int id2,vtkPoints id3,vtkIncrementalPointLocator id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8)
    { TriangulateFace_30(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native int GetNumberOfVerticesOnFace_31(int id0);
  public int GetNumberOfVerticesOnFace(int id0)
    { return GetNumberOfVerticesOnFace_31(id0); }

  public vtkGenericAdaptorCell() { super(); }

  public vtkGenericAdaptorCell(long id) { super(id); }

}
